*********
Changelog
*********


Version 1.1.6 (2025-01-31)
==========================

Other
-----
- Replaced gitchangelog with git-cliff.


Version 1.1.5 (2025-01-22)
==========================

Added
-----
- Adds PyPi Homepage url.

Fixed
-----
- Fixes bug #7.


Version 1.1.4 (2024-12-23)
==========================

Other
-----
- Made the assert and report checks more robust for queries not returning a single boolean. This fixes the second part of issue #6.

Version 1.1.3 (2024-12-21)
==========================

Other
-----
- Made rich text evaluation more robust for complex results.


Version 1.1.2 (2024-12-20)
==========================

Other
-----
- Bumped required elementpath version to fix bug #6.


Version 1.1.1 (2024-11-27)
==========================

Other
-----
- Updated is_valid comment in the API.


Version 1.1.0 (2024-11-27)
==========================

Other
-----
- Fixes github bug #5. The reporting of the is_valid method was reversed with regard to assert/report.
- Fixed the documentation regarding the is_valid function.


Version 1.0.3 (2024-10-29)
==========================

Other
-----
- Updated elementpath dependency version.


Version 1.0.2 (2024-10-18)
==========================

Other
-----
- Updated readme to include supported Python version and other textual changes.
- Updated lxml dependency from 5.1.0 to 5.2.1


Version 1.0.1 (2024-09-24)
==========================

Other
-----
- Upgraded to elementpath==4.5.0
- Fixed email address in info blocks.


Version 1.0.0 (2024-08-23)
==========================

Other
-----
First complete version of PySchematron. See the readme for the functionality and limitations.


Version 0.1.0 (2022-09-12)
==========================

Other
-----
- First version



